#!/usr/bin/env python

from distutils.core import setup

setup(
    name='kh-pypi-test',
    version='0.5',
    description='A trivial test project to upload to PyPi',
    long_description='Some long description of this fake egg...nothing here; move along now',
    author='Kyle Hornberg',
    author_email='kyle.hornberg@gmail.com',
    url='https://github.com/khornberg/pypi',
    packages=['kh_pypi_test'],
)
